@@ -1,4 +1,4 @@
-__version__ = "0.6.4"
+__version__ = "0.9.0"
 __package__ = "oneai"
 
 from typing_extensions import Final
@@ -18,6 +18,11 @@ api_key = None
 Default api key to use. You can use different keys for different pipelines by setting the `Pipeline.api_key` attribute or passing an `api_key` parameter to `Pipeline.run` calls.
 """
 
+multilingual = False
+"""
+Whether to allow multilingual inputs by default. You can use different values for different pipelines by setting the `Pipeline.multilingual` attribute or passing a `multilingual` parameter to `Pipeline.run` calls.
+"""
+
 MAX_CONCURRENT_REQUESTS: Final[int] = 2
 """
 Max number of allowed concurrent requests to be made by the SDK.
