@@ -1,6 +1,5 @@
 from dataclasses import dataclass, field
 from datetime import datetime
-import json
 import urllib.parse
 from typing import Generator, List, Union
 from typing_extensions import Literal
@@ -19,7 +18,7 @@ def get_collections(
     yield from get_clustering_paginated(
         "",
         api_key,
-        'collections',
+        "collections",
         None,
         from_dict=Collection,
         limit=limit,
@@ -27,9 +26,8 @@ def get_collections(
 
 
 @dataclass
-class Item:
+class Item(Input[str]):
     id: int
-    text: str
     created_at: datetime
     distance: float
     phrase: "Phrase" = field(repr=False)
@@ -46,6 +44,9 @@ class Item:
             distance=object["distance_to_phrase"],
             phrase=phrase,
             cluster=phrase.cluster,
+            metadata=object["metadata"],
+            type="article",
+            content_type="text/plain",
         )
 
 
@@ -56,6 +57,7 @@ class Phrase:
     item_count: int
     cluster: "Cluster" = field(repr=False)
     collection: "Collection" = field(repr=False)
+    metadata: dict = field(default_factory=dict)
 
     def get_items(
         self,
@@ -66,7 +68,7 @@ class Phrase:
         yield from get_clustering_paginated(
             f"{self.collection.id}/phrases/{self.id}/items",
             self.collection.api_key,
-            'items',
+            "items",
             self,
             Item.from_dict,
             limit=limit,
@@ -82,6 +84,7 @@ class Phrase:
             item_count=object["items_count"],
             cluster=cluster,
             collection=cluster.collection,
+            metadata=object["metadata"],
         )
 
 
@@ -91,8 +94,8 @@ class Cluster:
     text: str
     phrase_count: int
     item_count: int
-    metadata: str
     collection: "Collection" = field(repr=False)
+    metadata: dict = field(default_factory=dict)
 
     def get_phrases(
         self,
@@ -107,7 +110,7 @@ class Cluster:
         yield from get_clustering_paginated(
             f"{self.collection.id}/clusters/{self.id}/phrases",
             self.collection.api_key,
-            'phrases',
+            "phrases",
             self,
             Phrase.from_dict,
             sort,
@@ -118,12 +121,36 @@ class Cluster:
             item_metadata,
         )
 
+    def get_items(
+        self,
+        *,
+        sort: Literal["ASC", "DESC"] = "ASC",
+        limit: int = None,
+        from_date: Union[datetime, str] = None,
+        to_date: Union[datetime, str] = None,
+        date_format: str = API_DATE_FORMAT,
+        item_metadata: str = None,
+    ) -> Generator[Phrase, None, None]:
+        yield from get_clustering_paginated(
+            f"{self.collection.id}/clusters/{self.id}/items",
+            self.collection.api_key,
+            "items",
+            self,
+            Item.from_dict,
+            sort,
+            limit,
+            from_date,
+            to_date,
+            date_format,
+            item_metadata,
+        )
+
     def add_items(self, items: List[PipelineInput[str]]):
         url = f"{self.collection.id}/items"
         data = [
             {
                 "text": item.text if isinstance(item, Input) else item,
-                "metadata": item.metadata if isinstance(item, Input) else None,
+                "item_metadata": item.metadata if isinstance(item, Input) else None,
                 "force-cluster-id": self.id,
             }
             for item in items
@@ -137,8 +164,8 @@ class Cluster:
             text=object["cluster_phrase"],
             phrase_count=object["phrases_count"],
             item_count=object["items_count"],
-            metadata=object["metadata"],
             collection=collection,
+            metadata=object["metadata"],
         )
 
 
@@ -160,7 +187,7 @@ class Collection:
         yield from get_clustering_paginated(
             f"{self.id}/clusters",
             self.api_key,
-            'clusters',
+            "clusters",
             self,
             Cluster.from_dict,
             sort,
@@ -186,17 +213,19 @@ class Collection:
     def add_items(
         self, items: List[PipelineInput[str]], force_new_clusters: bool = False
     ):
-        url = f"{self.id}/items"
-        data = [
-            {
-                "text": item.text if isinstance(item, Input) else item,
-                "metadata": json.dumps(item.metadata)
-                if isinstance(item, Input)
-                else None,
+        def build_item(input: PipelineInput[str]):
+            result = {
+                "text": input.text if isinstance(input, Input) else str(input),
                 "force-new-cluster": force_new_clusters,
             }
-            for item in items
-        ]
+            if hasattr(input, "metadata") and input.metadata:
+                result["item_metadata"] = input.metadata
+            if hasattr(input, "timestamp") and input.timestamp:
+                result["timestamp"] = input.timestamp
+            return result
+
+        url = f"{self.id}/items"
+        data = [build_item(item) for item in items]
         print(post_clustering(url, data, self.api_key))
 
     def __repr__(self) -> str:
