@@ -1,8 +1,9 @@
 from dataclasses import dataclass
 from typing import List
+from typing_extensions import Literal
 from warnings import warn
 
-from oneai.classes import Document, Labels, Skill, Utterance, skillclass, Output
+from oneai.classes import Labels, Skill, Utterance, skillclass, Output
 
 
 @skillclass(
@@ -576,7 +577,7 @@ class SalesInsights(Skill):
 
 @skillclass(
     api_name="service-email-insights",
-    label_type="service-insights",
+    label_type="service-email-insights",
     output_attr="service_insights",
 )
 class ServiceInsights(Skill):
@@ -598,6 +599,30 @@ class ServiceInsights(Skill):
     """
 
 
+@skillclass(
+    api_name="service-email-insights",
+    label_type="service-email-insights",
+    output_attr="email_insights",
+)
+class EmailInsights(Skill):
+    """
+    Finds spans in the text with Email Insights.
+
+    ## Output Attributes
+
+    `email_insights: list[Label]`
+        A list of `Label` objects, with detected email insights
+
+    ## Example
+
+    >>> pipeline = oneai.Pipeline(steps=[
+    ...     oneai.skills.EmailInsights()
+    ... ])
+    >>> output = pipeline.run('...')
+    >>> output.email_insights
+    """
+
+
 @skillclass(
     api_name="detect-language", label_type="detect-language", output_attr="language"
 )
@@ -688,6 +713,7 @@ class Transcribe(Skill):
 
     speaker_detection: bool = True
     timestamp_per_word: bool = False
+    engine: Literal["default", "whisper"] = "default"
 
 
 @skillclass(api_name="clustering")
@@ -707,7 +733,6 @@ class Clustering(Skill):
 
     collection: str = ""
     input_skill: str = ""
-    item_metadata: dict = ""
 
 
 class OutputAttrs:
